FailureCode

Enum FailureCode 

pub enum FailureCode {
    MissingRequiredInput,
    StaleSnapshot,
    ConflictingSource,
    UnmappedProviderValue,
    MissingPolicy,
    CapacityUnavailable,
    PolicyHardStop,
    MissingOrUnverifiedVaccine,
    DepositNotSatisfied,
    BehaviorExceptionRequiresReview,
    SpecialCareRequiresReview,
}
Classifies failure code values that drive the booking-readiness workflow.

Variants



MissingRequiredInput

Identifies missing required input as the reason the workflow must stop, retry, or request review.



StaleSnapshot

Identifies stale snapshot as the reason the workflow must stop, retry, or request review.



ConflictingSource

Identifies conflicting source as the reason the workflow must stop, retry, or request review.



UnmappedProviderValue

Identifies unmapped provider value as the reason the workflow must stop, retry, or request review.



MissingPolicy

Identifies missing policy as the reason the workflow must stop, retry, or request review.



CapacityUnavailable

Identifies capacity unavailable as the reason the workflow must stop, retry, or request review.



PolicyHardStop

Identifies policy hard stop as the reason the workflow must stop, retry, or request review.



MissingOrUnverifiedVaccine

Identifies missing or unverified vaccine as the reason the workflow must stop, retry, or request review.



DepositNotSatisfied

Identifies deposit not satisfied as the reason the workflow must stop, retry, or request review.



BehaviorExceptionRequiresReview

Identifies behavior exception requires review as the reason the workflow must stop, retry, or request review.



SpecialCareRequiresReview

Identifies special care requires review as the reason the workflow must stop, retry, or request review.