ReadinessBucket

Enum ReadinessBucket 

pub enum ReadinessBucket {
    ReadyForStaffApproval,
    MissingInfo,
    VaccinePending,
    SpecialReview,
    Waitlisted,
    Offered,
    Confirmed,
    Rejected,
    FailedSafely,
}
Deterministic booking status bucket used to prioritize staff review.

Variants



ReadyForStaffApproval

Prioritizes reservations that are ready for staff approval for staff triage queues.



MissingInfo

Prioritizes reservations that are missing info for staff triage queues.



VaccinePending

Prioritizes reservations that are vaccine pending for staff triage queues.



SpecialReview

Prioritizes reservations that are special review for staff triage queues.



Waitlisted

Prioritizes reservations that are waitlisted for staff triage queues.



Offered

Prioritizes reservations that are offered for staff triage queues.



Confirmed

Prioritizes reservations that are confirmed for staff triage queues.



Rejected

Prioritizes reservations that are rejected for staff triage queues.



FailedSafely

Prioritizes reservations that are failed safely for staff triage queues.