pub struct PetProfileAttached(pub PetProfile);Tuple Fields
0: PetProfileTrait Implementations
Sourceimpl CanTransitionMap<PetProfileAttached> for Request<Intake>
impl CanTransitionMap<PetProfileAttached> for Request<Intake>
Sourcetype CurrentData = <Request<Intake> as DeclaredTransitionMapEdge<PetProfileAttached>>::CurrentData
type CurrentData = <Request<Intake> as DeclaredTransitionMapEdge<PetProfileAttached>>::CurrentData
The payload type stored in the current state.
Sourcetype Output = Request<PetProfileAttached>
type Output = Request<PetProfileAttached>
The transition result type.
Sourcefn transition_map<F>(self, f: F) -> Self::Outputwhere
F: FnOnce(Self::CurrentData) -> <PetProfileAttached as StateMarker>::Data,
fn transition_map<F>(self, f: F) -> Self::Outputwhere
F: FnOnce(Self::CurrentData) -> <PetProfileAttached as StateMarker>::Data,
Perform the transition by consuming the current state data and producing the next payload.
Sourceimpl Clone for PetProfileAttached
impl Clone for PetProfileAttached
Sourcefn clone(&self) -> PetProfileAttached
fn clone(&self) -> PetProfileAttached
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PetProfileAttached
impl Debug for PetProfileAttached
Sourceimpl PartialEq for PetProfileAttached
impl PartialEq for PetProfileAttached
Sourceimpl RequestStateTrait for PetProfileAttached
impl RequestStateTrait for PetProfileAttached
type Data = PetProfile
Sourceimpl StateMarker for PetProfileAttached
impl StateMarker for PetProfileAttached
Sourcetype Data = PetProfile
type Data = PetProfile
The payload type stored in machines for this state.
impl DataState for PetProfileAttached
impl Eq for PetProfileAttached
impl StructuralPartialEq for PetProfileAttached