pub struct PolicyAttached(pub PolicyAttachedData);Tuple Fields
0: PolicyAttachedDataTrait Implementations
Sourceimpl CanTransitionMap<PolicyAttached> for Request<PetProfileAttached>
impl CanTransitionMap<PolicyAttached> for Request<PetProfileAttached>
Sourcetype CurrentData = <Request<PetProfileAttached> as DeclaredTransitionMapEdge<PolicyAttached>>::CurrentData
type CurrentData = <Request<PetProfileAttached> as DeclaredTransitionMapEdge<PolicyAttached>>::CurrentData
The payload type stored in the current state.
Sourcetype Output = Request<PolicyAttached>
type Output = Request<PolicyAttached>
The transition result type.
Sourcefn transition_map<F>(self, f: F) -> Self::Outputwhere
F: FnOnce(Self::CurrentData) -> <PolicyAttached as StateMarker>::Data,
fn transition_map<F>(self, f: F) -> Self::Outputwhere
F: FnOnce(Self::CurrentData) -> <PolicyAttached as StateMarker>::Data,
Perform the transition by consuming the current state data and producing the next payload.
Sourceimpl Clone for PolicyAttached
impl Clone for PolicyAttached
Sourcefn clone(&self) -> PolicyAttached
fn clone(&self) -> PolicyAttached
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PolicyAttached
impl Debug for PolicyAttached
Sourceimpl PartialEq for PolicyAttached
impl PartialEq for PolicyAttached
Sourceimpl RequestStateTrait for PolicyAttached
impl RequestStateTrait for PolicyAttached
type Data = PolicyAttachedData
Sourceimpl StateMarker for PolicyAttached
impl StateMarker for PolicyAttached
Sourcetype Data = PolicyAttachedData
type Data = PolicyAttachedData
The payload type stored in machines for this state.
impl DataState for PolicyAttached
impl Eq for PolicyAttached
impl StructuralPartialEq for PolicyAttached