pub struct ReadyForPolicyDecision(pub PolicyAttachedData);Tuple Fields
0: PolicyAttachedDataTrait Implementations
Sourceimpl CanTransitionMap<ReadyForPolicyDecision> for Request<PolicyAttached>
impl CanTransitionMap<ReadyForPolicyDecision> for Request<PolicyAttached>
Sourcetype CurrentData = <Request<PolicyAttached> as DeclaredTransitionMapEdge<ReadyForPolicyDecision>>::CurrentData
type CurrentData = <Request<PolicyAttached> as DeclaredTransitionMapEdge<ReadyForPolicyDecision>>::CurrentData
The payload type stored in the current state.
Sourcetype Output = Request<ReadyForPolicyDecision>
type Output = Request<ReadyForPolicyDecision>
The transition result type.
Sourcefn transition_map<F>(self, f: F) -> Self::Outputwhere
F: FnOnce(Self::CurrentData) -> <ReadyForPolicyDecision as StateMarker>::Data,
fn transition_map<F>(self, f: F) -> Self::Outputwhere
F: FnOnce(Self::CurrentData) -> <ReadyForPolicyDecision as StateMarker>::Data,
Perform the transition by consuming the current state data and producing the next payload.
Sourceimpl Clone for ReadyForPolicyDecision
impl Clone for ReadyForPolicyDecision
Sourcefn clone(&self) -> ReadyForPolicyDecision
fn clone(&self) -> ReadyForPolicyDecision
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReadyForPolicyDecision
impl Debug for ReadyForPolicyDecision
Sourceimpl PartialEq for ReadyForPolicyDecision
impl PartialEq for ReadyForPolicyDecision
Sourceimpl StateMarker for ReadyForPolicyDecision
impl StateMarker for ReadyForPolicyDecision
Sourcetype Data = PolicyAttachedData
type Data = PolicyAttachedData
The payload type stored in machines for this state.
impl DataState for ReadyForPolicyDecision
impl Eq for ReadyForPolicyDecision
impl StructuralPartialEq for ReadyForPolicyDecision