Request

Struct Request 

pub struct Request<RequestState: RequestStateTrait = UninitializedRequestState> {
    pub state_data: RequestState::Data,
    /* private fields */
}

Fields

state_data: RequestState::Data

Implementations

Source

impl<RequestState: RequestStateTrait> Request<RequestState>

pub fn transition_map<N, F>(self, f: F) -> Request<N>
where N: RequestStateTrait + StateMarker, Self: DeclaredTransitionMapEdge<N>, F: FnOnce(<Self as DeclaredTransitionMapEdge<N>>::CurrentData) -> <N as StateMarker>::Data,

Source

impl Request<Intake>

pub fn builder() -> RequestIntakeBuilder<__StatumRequestIntakeBuilderMissingSlot0Reservation>

Source

impl Request<PetProfileAttached>

pub fn builder() -> RequestPetProfileAttachedBuilder<__StatumRequestPetProfileAttachedBuilderMissingSlot0StateData, __StatumRequestPetProfileAttachedBuilderMissingSlot1Reservation>

Source

impl Request<PolicyAttached>

pub fn builder() -> RequestPolicyAttachedBuilder<__StatumRequestPolicyAttachedBuilderMissingSlot0StateData, __StatumRequestPolicyAttachedBuilderMissingSlot1Reservation>

Source

impl Request<ReadyForPolicyDecision>

pub fn builder() -> RequestReadyForPolicyDecisionBuilder<__StatumRequestReadyForPolicyDecisionBuilderMissingSlot0StateData, __StatumRequestReadyForPolicyDecisionBuilderMissingSlot1Reservation>

Source

impl Request<Intake>

pub fn attach_pet_profile( self, name: Name, completeness: PetProfileCompleteness, ) -> Request<PetProfileAttached>

Attaches pet profile evidence before the request can move to policy decisioning.

Source

impl Request<PetProfileAttached>

pub fn attach_policy_snapshot( self, policy_snapshot: PolicySnapshot, ) -> Request<PolicyAttached>

Attaches policy snapshot evidence before the request can move to policy decisioning.

Source

impl Request<PolicyAttached>

pub fn mark_ready_for_policy_decision(self) -> Request<ReadyForPolicyDecision>

Marks the packet as ready for policy decision once required evidence has been attached.

Source

impl<S: RequestStateTrait> Request<S>

pub fn reservation(&self) -> &Reservation

Returns the reservation carried by this booking-readiness workflow value.