pub enum ApprovalGate {
None,
StaffApproval,
ManagerApproval,
MedicalDocumentReview,
BehaviorReview,
CareTeamApproval,
PaymentManagerApproval,
CustomerMessageApproval,
ConfirmedBookingAutomation,
RejectionApproval,
}Expand description
Human approval checkpoints that must clear before the workflow can advance.
Variants
None
Requires none before staff can rely on the packet for the next workflow step.
StaffApproval
Requires staff approval before staff can rely on the packet for the next workflow step.
ManagerApproval
Requires manager approval before staff can rely on the packet for the next workflow step.
MedicalDocumentReview
Requires medical document review before staff can rely on the packet for the next workflow step.
BehaviorReview
Requires behavior review before staff can rely on the packet for the next workflow step.
CareTeamApproval
Requires care team approval before staff can rely on the packet for the next workflow step.
PaymentManagerApproval
Requires payment manager approval before staff can rely on the packet for the next workflow step.
CustomerMessageApproval
Requires customer message approval before staff can rely on the packet for the next workflow step.
ConfirmedBookingAutomation
Requires confirmed booking automation before staff can rely on the packet for the next workflow step.
RejectionApproval
Requires rejection approval before staff can rely on the packet for the next workflow step.