pub struct Request<RequestState: RequestStateTrait = UninitializedRequestState> {
pub state_data: RequestState::Data,
/* private fields */
}Fields
state_data: RequestState::DataImplementations
Sourceimpl<RequestState: RequestStateTrait> Request<RequestState>
impl<RequestState: RequestStateTrait> Request<RequestState>
pub fn transition_map<N, F>(self, f: F) -> Request<N>where
N: RequestStateTrait + StateMarker,
Self: DeclaredTransitionMapEdge<N>,
F: FnOnce(<Self as DeclaredTransitionMapEdge<N>>::CurrentData) -> <N as StateMarker>::Data,
Sourceimpl Request<PolicyAttached>
impl Request<PolicyAttached>
Sourceimpl Request<Intake>
impl Request<Intake>
Sourcepub fn attach_pet_profile(
self,
name: Name,
completeness: PetProfileCompleteness,
) -> Request<PetProfileAttached>
pub fn attach_pet_profile( self, name: Name, completeness: PetProfileCompleteness, ) -> Request<PetProfileAttached>
Attaches pet profile evidence before the request can move to policy decisioning.
Sourceimpl Request<PetProfileAttached>
impl Request<PetProfileAttached>
Sourcepub fn attach_policy_snapshot(
self,
policy_snapshot: PolicySnapshot,
) -> Request<PolicyAttached>
pub fn attach_policy_snapshot( self, policy_snapshot: PolicySnapshot, ) -> Request<PolicyAttached>
Attaches policy snapshot evidence before the request can move to policy decisioning.
Sourceimpl Request<PolicyAttached>
impl Request<PolicyAttached>
Sourcepub fn mark_ready_for_policy_decision(self) -> Request<ReadyForPolicyDecision>
pub fn mark_ready_for_policy_decision(self) -> Request<ReadyForPolicyDecision>
Marks the packet as ready for policy decision once required evidence has been attached.
Sourceimpl<S: RequestStateTrait> Request<S>
impl<S: RequestStateTrait> Request<S>
Sourcepub fn reservation(&self) -> &Reservation
pub fn reservation(&self) -> &Reservation
Returns the reservation carried by this booking-readiness workflow value.